pybet365 package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pybet365.client
   pybet365.response

Submodules
----------

pybet365.cli module
-------------------

.. automodule:: pybet365.cli
   :members:
   :undoc-members:
   :show-inheritance:

pybet365.pybet365 module
------------------------

.. automodule:: pybet365.pybet365
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pybet365
   :members:
   :undoc-members:
   :show-inheritance:
